# cpupower-python

[![PyPI version](https://badge.fury.io/py/cpupower.svg)](https://badge.fury.io/py/cpupower)
[![Build status](https://ci.appveyor.com/api/projects/status/it86j7ypo815o83l/branch/master?svg=true)](https://ci.appveyor.com/project/minkcrypto/cpupower-python/branch/master)

This package implements the hashing algorithm used by CPUchain.

## Install

```bash
$ pip install cpupower
```

## Usage

```python
    import cpupower
```
